==> jclouds-2.4.0-source-release.tar.gz: jclouds-2.4.0/providers/digitalocean2/src/main/java/org/jclouds/digitalocean2/handlers/DigitalOcean2RateLimitRetryHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.digitalocean2.handlers;

import javax.inject.Singleton;

import org.jclouds.http.HttpCommand;
import org.jclouds.http.HttpResponse;
import org.jclouds.http.handlers.RateLimitRetryHandler;

import com.google.common.base.Optional;

@Singleton
public class DigitalOcean2RateLimitRetryHandler extends RateLimitRetryHandler {

   @Override
   protected Optional<Long> millisToNextAvailableRequest(HttpCommand command, HttpResponse response) {
      // The header is the Unix epoch time when the next request can be done
      String epochForNextAvailableRequest = response.getFirstHeaderOrNull("RateLimit-Reset");
      if (epochForNextAvailableRequest == null) {
         return Optional.absent();
      }
      return Optional.of(millisUntilNextAvailableRequest(Long.parseLong(epochForNextAvailableRequest)));
   }

   public static long millisUntilNextAvailableRequest(long epochForNextAvailableRequest) {
      return (epochForNextAvailableRequest * 1000) - System.currentTimeMillis();
   }

   
}

==> jclouds-2.7.0-source-release.tar.gz: jclouds-2.7.0/providers/digitalocean2/src/main/java/org/jclouds/digitalocean2/handlers/DigitalOcean2RateLimitRetryHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.digitalocean2.handlers;

import jakarta.inject.Singleton;

import org.jclouds.http.HttpCommand;
import org.jclouds.http.HttpResponse;
import org.jclouds.http.handlers.RateLimitRetryHandler;

import com.google.common.base.Optional;

@Singleton
public class DigitalOcean2RateLimitRetryHandler extends RateLimitRetryHandler {

   @Override
   protected Optional<Long> millisToNextAvailableRequest(HttpCommand command, HttpResponse response) {
      // The header is the Unix epoch time when the next request can be done
      String epochForNextAvailableRequest = response.getFirstHeaderOrNull("RateLimit-Reset");
      if (epochForNextAvailableRequest == null) {
         return Optional.absent();
      }
      return Optional.of(millisUntilNextAvailableRequest(Long.parseLong(epochForNextAvailableRequest)));
   }

   public static long millisUntilNextAvailableRequest(long epochForNextAvailableRequest) {
      return (epochForNextAvailableRequest * 1000) - System.currentTimeMillis();
   }

   
}
